@@ -1,9 +1,7 @@
-from __future__ import print_function
 import eyed3
 from eyed3.plugins import Plugin
 from eyed3.utils import guessMimetype
 
-eyed3.require((0, 7))
 
 class EchoPlugin(eyed3.plugins.Plugin):
     NAMES = ["echo"]
